@@ -21,14 +21,10 @@ sys.path.insert(0, os.path.abspath('../..'))
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
     'sphinxcontrib.apidoc',
+    'sphinxcontrib.rsvgconverter',
+    'openstackdocstheme',
 ]
 
-try:
-    import openstackdocstheme
-    extensions.append('openstackdocstheme')
-except ImportError:
-    openstackdocstheme = None
-
 autoclass_content = 'both'
 apidoc_module_dir = '../../metalsmith'
 apidoc_output_dir = 'reference/api'
@@ -46,19 +42,8 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'metalsmith'
 copyright = u'2018, MetalSmith Developers '
 
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
-#
-from metalsmith import version as ms_version  # noqa
-# The full version, including alpha/beta/rc tags.
-release = ms_version.version_info.release_string()
-# The short X.Y version.
-version = ms_version.version_info.version_string()
-
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
 
@@ -67,7 +52,11 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
+
+openstackdocs_repo_name = 'openstack/metalsmith'
+openstackdocs_bug_project = 'metalsmith'
+openstackdocs_bug_tag = ''
 
 # -- Options for HTML output --------------------------------------------------
 
@@ -77,21 +66,20 @@ pygments_style = 'sphinx'
 # html_theme = '_theme'
 # html_static_path = ['static']
 
-if openstackdocstheme is not None:
-    html_theme = 'openstackdocs'
-else:
-    html_theme = 'default'
+html_theme = 'openstackdocs'
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = '%sdoc' % project
+htmlhelp_basename = 'metalsmithdoc'
+
+latex_use_xindy = False
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass
 # [howto/manual]).
 latex_documents = [
     ('index',
-     '%s.tex' % project,
-     u'%s Documentation' % project,
+     'doc-metalsmith.tex',
+     u'MetalSmith Documentation',
      u'MetalSmith Developers', 'manual'),
 ]
 
