@@ -13,11 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import fixtures
-import mock
+import unittest
+from unittest import mock
+
 from openstack import exceptions as os_exc
 import requests
-import testtools
 
 from metalsmith import _instance
 from metalsmith import _provisioner
@@ -33,7 +33,7 @@ NODE_FIELDS = ['name', 'id', 'instance_info', 'instance_id', 'is_maintenance',
                'allocation_id']
 
 
-class TestInit(testtools.TestCase):
+class TestInit(unittest.TestCase):
     def test_missing_auth(self):
         self.assertRaisesRegex(TypeError, 'must be provided',
                                _provisioner.Provisioner)
@@ -57,7 +57,7 @@ class TestInit(testtools.TestCase):
         mock_conn.assert_called_once_with(config=region)
 
 
-class Base(testtools.TestCase):
+class Base(unittest.TestCase):
 
     def setUp(self):
         super(Base, self).setUp()
@@ -72,9 +72,11 @@ class Base(testtools.TestCase):
         self.node.name = 'control-0'
 
     def _reset_api_mock(self):
-        self.mock_get_node = self.useFixture(
-            fixtures.MockPatchObject(_provisioner.Provisioner, '_get_node',
-                                     autospec=True)).mock
+        get_node_patcher = mock.patch.object(
+            _provisioner.Provisioner, '_get_node', autospec=True)
+        self.mock_get_node = get_node_patcher.start()
+        self.addCleanup(get_node_patcher.stop)
+
         self.mock_get_node.side_effect = (
             lambda self, n, refresh=False: n
         )
@@ -91,7 +93,7 @@ class Base(testtools.TestCase):
         self.pr.connection = self.api
 
 
-class TestGetFindNode(testtools.TestCase):
+class TestGetFindNode(unittest.TestCase):
 
     def setUp(self):
         super(TestGetFindNode, self).setUp()
@@ -502,10 +504,12 @@ class TestProvisionNode(Base):
                 self.api.network.create_port.return_value.id
             ],
         }
-        self.configdrive_mock = self.useFixture(
-            fixtures.MockPatchObject(instance_config.GenericConfig,
-                                     'generate', autospec=True)
-        ).mock
+
+        configdrive_patcher = mock.patch.object(
+            instance_config.GenericConfig, 'generate', autospec=True)
+        self.configdrive_mock = configdrive_patcher.start()
+        self.addCleanup(configdrive_patcher.stop)
+
         self.api.baremetal.get_node.side_effect = lambda _n: self.node
         self.api.baremetal.get_allocation.side_effect = (
             lambda _a: self.allocation)
@@ -518,7 +522,9 @@ class TestProvisionNode(Base):
         self.assertEqual(inst.node, self.node)
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -580,7 +586,9 @@ class TestProvisionNode(Base):
         self.assertEqual(inst.node, self.node)
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -604,7 +612,9 @@ class TestProvisionNode(Base):
         config.generate.assert_called_once_with(self.node,
                                                 self.allocation.name)
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -641,7 +651,9 @@ class TestProvisionNode(Base):
         self.api.baremetal.update_allocation.assert_called_once_with(
             self.allocation, name=hostname)
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='control-0.example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -667,7 +679,9 @@ class TestProvisionNode(Base):
 
         self.assertFalse(self.api.baremetal.update_allocation.called)
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='control-0.example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -695,7 +709,9 @@ class TestProvisionNode(Base):
 
         self.assertFalse(self.api.baremetal.update_allocation.called)
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='control-0.example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -750,7 +766,9 @@ class TestProvisionNode(Base):
         self.api.baremetal.update_allocation.assert_called_once_with(
             self.allocation, name=self.node.name)
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='control-0-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -781,7 +799,9 @@ class TestProvisionNode(Base):
         self.assertIs(inst.allocation, self.allocation)
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='000-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -813,7 +833,11 @@ class TestProvisionNode(Base):
             mock.call(self.node.id)
         ])
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='%s-%s' % (
+                self.api.baremetal.wait_for_allocation.return_value.name,
+                self.api.network.find_network.return_value.name
+            ))
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -846,7 +870,11 @@ class TestProvisionNode(Base):
             mock.call(self.node.id)
         ])
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='%s-%s' % (
+                self.api.baremetal.wait_for_allocation.return_value.name,
+                self.api.network.find_network.return_value.name
+            ))
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -908,6 +936,8 @@ class TestProvisionNode(Base):
 
         self.api.network.create_port.assert_called_once_with(
             network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name,
             fixed_ips=[{'ip_address': '10.0.0.2'}])
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
@@ -929,6 +959,8 @@ class TestProvisionNode(Base):
 
         self.api.network.create_port.assert_called_once_with(
             network_id=self.api.network.get_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.get_network.return_value.name,
             fixed_ips=[{'subnet_id':
                         self.api.network.find_subnet.return_value.id}])
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
@@ -954,7 +986,9 @@ class TestProvisionNode(Base):
         self.pr.provision_node(self.node, 'image', [{'network': 'network'}])
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -982,7 +1016,9 @@ class TestProvisionNode(Base):
 
         self.assertFalse(self.api.image.find_image.called)
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1017,7 +1053,9 @@ abcd  image
         self.assertFalse(self.api.image.find_image.called)
         mock_get.assert_called_once_with('https://host/checksums')
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1048,7 +1086,9 @@ abcd  image
 
         self.assertFalse(self.api.image.find_image.called)
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1076,7 +1116,9 @@ abcd  image
 
         self.assertFalse(self.api.image.find_image.called)
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1107,7 +1149,9 @@ abcd  image
 
         self.assertFalse(self.api.image.find_image.called)
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1126,7 +1170,9 @@ abcd  image
                                root_size_gb=50)
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1145,7 +1191,9 @@ abcd  image
                                swap_size_mb=4096)
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1168,7 +1216,9 @@ abcd  image
         self.assertEqual(inst.node, self.node)
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1191,7 +1241,9 @@ abcd  image
         self.assertEqual(inst.node, self.node)
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1216,7 +1268,9 @@ abcd  image
         self.assertEqual(inst.node, self.node)
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1238,7 +1292,9 @@ abcd  image
         self.assertEqual(inst.node, self.node)
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1261,7 +1317,9 @@ abcd  image
         self.assertEqual(inst.node, self.node)
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1282,7 +1340,9 @@ abcd  image
                                wait=3600)
 
         self.api.network.create_port.assert_called_once_with(
-            network_id=self.api.network.find_network.return_value.id)
+            network_id=self.api.network.find_network.return_value.id,
+            name='example.com-%s' %
+            self.api.network.find_network.return_value.name)
         self.api.baremetal.attach_vif_to_node.assert_called_once_with(
             self.node, self.api.network.create_port.return_value.id)
         self.api.baremetal.update_node.assert_called_once_with(
@@ -1877,7 +1937,7 @@ class TestUnprovisionNode(Base):
         self.assertFalse(self.api.baremetal.update_node.called)
 
 
-class TestShowInstance(testtools.TestCase):
+class TestShowInstance(unittest.TestCase):
     def setUp(self):
         super(TestShowInstance, self).setUp()
         self.pr = _provisioner.Provisioner(mock.Mock())
